Installation — GromacsWrapper 0.5.0-dev documentation

# Installation

The package contains two files, README and INSTALL, which should get you started quickly.

If everything works perfectly then you might be able to install a working version of GromacsWrapper with a simple

    python setup.py install

from the unpacked sources.

- README: GromacsWrapper
  - Licence
  - Included Software
  - Citing
  - Download and Availability
  - Contact
- INSTALL
  - Quick installation instructions
  - Manual Download
  - Source code access
  - Requirements